"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataParser = void 0;
var wcag_1 = require("./wcag");
var manualCheckObj_1 = require("./manualCheckObj");
exports.dataParser = function (dataToBeParsed) {
    // sort issues into common occurances i.e. { critical: [resultItem1, resultItem2], severe: [resultItem3]}
    var data = dataToBeParsed.reduce(function (parsedData, curIssue) {
        var _a;
        var specificIssuePopulator = function (node) {
            var parsedSpecificIssue = {};
            parsedSpecificIssue.recommendation = node.failureSummary;
            parsedSpecificIssue.html = node.html;
            return parsedSpecificIssue;
        };
        // default values for no given wcag information
        var wcagURLInfo = curIssue.helpUrl;
        var wcagCriteriaInfo = 'n/a';
        var foundFlag = false;
        // parse through wcag.ts object to see if we've added a dq_id 
        var wcagConnector = function () {
            var id = curIssue.id;
            for (var i = 0; i < wcag_1.wcag.principles.length; i += 1) {
                for (var j = 0; j < wcag_1.wcag.principles[i].guidelines.length; j += 1) {
                    for (var k = 0; k < wcag_1.wcag.principles[i].guidelines[j].successcriteria.length; k += 1) {
                        var location_1 = wcag_1.wcag.principles[i].guidelines[j].successcriteria[k];
                        if (location_1.dq_id && location_1.dq_id.includes(id)) {
                            foundFlag = true;
                            wcagURLInfo = location_1.url;
                            wcagCriteriaInfo = location_1.num;
                            break;
                        }
                    }
                    if (foundFlag)
                        break;
                }
                if (foundFlag)
                    break;
            }
        };
        var issuesPopulator = function () {
            var parsedIssue = {};
            wcagConnector();
            parsedIssue.dequeId = curIssue.id;
            parsedIssue.wcagCriteria = wcagCriteriaInfo; // wcag.principles[index].guidelines[0].successcriteria[0].num
            parsedIssue.urlToWCAG = wcagURLInfo; //  wcag.principles[index].guidelines[0].successcriteria[0].url
            parsedIssue.title = curIssue.help;
            parsedIssue.specificIssues = curIssue.nodes.map(function (node) { return specificIssuePopulator(node); });
            parsedIssue.impact = curIssue.impact;
            return parsedIssue;
        };
        var parsedIssue = issuesPopulator();
        if (curIssue.impact === null || curIssue.impact === undefined) {
            if (parsedData.nonEssential)
                parsedData.nonEssential.push(parsedIssue);
            else
                parsedData.nonEssential = [parsedIssue];
        }
        else if (parsedData[curIssue.impact]) {
            (_a = parsedData[curIssue.impact]) === null || _a === void 0 ? void 0 : _a.push(parsedIssue);
        }
        else {
            parsedData[curIssue.impact] = [parsedIssue];
        }
        return parsedData;
    }, {});
    // add manual tests to object
    data.manualTests = manualCheckObj_1.manualCheckObj;
    return data;
};
// Returned parsed example
// export const demoParsed = {
//   critical: [
//     {
//       dequeId: 'aria-required-attr',
//       wcagCriteria: 'n/a',
//       urlToWCAG: 'https://dequeuniversity.com/rules/axe/3.5/aria-required-attr?application=axe-puppeteer',
//       title: 'Required ARIA attributes must be provided',
//       specificIssues: [Array],
//       impact: 'critical'
//     }
//   ],
//   serious: [
//     {
//       dequeId: 'bypass',
//       wcagCriteria: 'n/a',
//       urlToWCAG: 'https://dequeuniversity.com/rules/axe/3.5/bypass?application=axe-puppeteer',
//       title: 'Page must have means to bypass repeated blocks',
//       specificIssues: [Array],
//       impact: 'serious'
//     }
//   ],
//   moderate: [
//     {
//       dequeId: 'landmark-one-main',
//       wcagCriteria: 'n/a',
//       urlToWCAG: 'https://dequeuniversity.com/rules/axe/3.5/landmark-one-main?application=axe-puppeteer',
//       title: 'Document must have one main landmark',
//       specificIssues: [Array],
//       impact: 'moderate'
//     },
//   ],
//   manualTests: [
//     {
//       title: 'For prerecorded audio-only and prerecorded video-only media, the following are true, except when the audio or video is a media alternative for text and is clearly labeled as such:',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/audio-only-and-video-only-prerecorded'
//     },
//     {
//       title: 'Captions are provided for all prerecorded audio content in synchronized media, except when the media is a media alternative for text and is clearly labeled as such.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/captions-prerecorded'
//     },
//     {
//       title: 'An alternative for time-based media or audio description of the prerecorded video content is provided for synchronized media, except when the media is a media alternative for text and is clearly labeled as such.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/audio-description-or-media-alternative-prerecorded'
//     },
//     {
//       title: 'When the sequence in which content is presented affects its meaning, a correct reading sequence can be programmatically determined.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/meaningful-sequence'
//     },
//     {
//       title: 'Instructions provided for understanding and operating content do not rely solely on sensory characteristics of components such as shape, color, size, visual location, orientation, or sound.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/sensory-characteristics'
//     },
//     {
//       title: 'If keyboard focus can be moved to a component of the page using a keyboard interface, then focus can be moved away from that component using only a keyboard interface, and, if it requires more than unmodified arrow or tab keys or other standard exit methods, the user is advised of the method for moving focus away.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/no-keyboard-trap'
//     },
//     {
//       title: 'If a keyboard shortcut is implemented in content using only letter (including upper- and lower-case letters), punctuation, number, or symbol characters, then at least one of the following is true:',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/character-key-shortcuts'
//     },
//     {
//       title: 'Web pages do not contain anything that flashes more than three times in any one second period, or the flash is below the general flash and red flash thresholds.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/three-flashes-or-below-threshold'
//     },
//     {
//       title: 'If a Web page can be navigated sequentially and the navigation sequences affect meaning or operation, focusable components receive focus in an order that preserves meaning and operability.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/focus-order'
//     },
//     {
//       title: 'All functionality that uses multipoint or path-based gestures for operation can be operated with a single pointer without a path-based gesture, unless a multipoint or path-based gesture is essential.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/pointer-gestures'
//     },
//     {
//       title: 'For functionality that can be operated using a single pointer, at least one of the following is true:',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/pointer-cancellation'
//     },
//     {
//       title: 'Functionality that can be operated by device motion or user motion can also be operated by user interface components and responding to the motion can be disabled to prevent accidental actuation, except when:',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/motion-actuation'
//     },
//     {
//       title: 'When any user interface component receives focus, it does not initiate a change of context.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/on-focus'
//     },
//     {
//       title: 'Changing the setting of any user interface component does not automatically cause a change of context unless the user has been advised of the behavior before using the component.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/on-input'
//     },
//     {
//       title: 'If an input error is automatically detected, the item that is in error is identified and the error is described to the user in text.',
//       urlToWCAG: 'https://www.w3.org/WAI/WCAG21/Understanding/error-identification'
//     }
//   ]
// }
