"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.menu = void 0;
var chalk_1 = __importDefault(require("chalk"));
exports.menu = {
    askMenu: function (results, targetLevel) {
        // process sorted issues into menu form
        var processed = [];
        Object.keys(results).forEach(function (issueLevel) {
            if (targetLevel) {
                if (targetLevel === 'manual')
                    targetLevel = 'manualTests';
                // Bottom level conditional: targetLevel is given...
                if (targetLevel.split(' ').length > 1) {
                    // ....and it is more than 1 word long
                    var targetLevelFlag_1 = false;
                    // Check the middle level to see if it was the targetLevel passed in
                    results[issueLevel].forEach(function (issue) {
                        if (issue.title === targetLevel)
                            targetLevelFlag_1 = true;
                    });
                    if (targetLevelFlag_1) {
                        // If so, process all three levels!
                        processed.push(exports.menu.processLevel(issueLevel, results[issueLevel], true)); // Top level: open
                        results[issueLevel].forEach(function (issue) {
                            if (issue.title === targetLevel) {
                                processed.push(exports.menu.processLevel(issue.title, issue.specificIssues, true, 1)); // Middle level: opened, indent
                                // wcag url for guidance
                                processed.push(exports.menu.processLevel(issue.urlToWCAG, [], false, 2));
                                processed.push(exports.menu.processLevel(issue.specificIssues[0].recommendation, [], false, 2));
                                issue.specificIssues.forEach(function (specificIssue) {
                                    // Bottom levels: (closed), double indent
                                    processed.push(exports.menu.processLevel(specificIssue.html, [], false, 2));
                                });
                            }
                            else {
                                // Middle level: closed, indent
                                processed.push(exports.menu.processLevel(issue.title, issue.specificIssues, false, 1));
                            }
                        });
                    }
                    else {
                        // Top level: closed
                        processed.push(exports.menu.processLevel(issueLevel, results[issueLevel]));
                    } // otherwise targetLevel given but only 1 words so looking for middle menu level
                }
                else if (targetLevel === issueLevel) {
                    processed.push(exports.menu.processLevel(issueLevel, results[issueLevel], true));
                    results[issueLevel].forEach(function (issue) {
                        processed.push(exports.menu.processLevel(issue.title, issue.specificIssues, false, 1));
                    });
                }
                else {
                    processed.push(exports.menu.processLevel(issueLevel, results[issueLevel]));
                }
            }
            else {
                // Base case: nothing selected, top level only!
                processed.push(exports.menu.processLevel(issueLevel, results[issueLevel]));
            }
        });
        // Stringify the array of processed menu options
        var options = processed.map(function (option) { return exports.menu.stringify(option); });
        return options;
    },
    processLevel: function (levelName, subLevel, opened, nested) {
        if (subLevel === void 0) { subLevel = []; }
        if (opened === void 0) { opened = false; }
        if (nested === void 0) { nested = 0; }
        return {
            levelName: levelName,
            opened: opened,
            nested: nested,
            subLevel: subLevel,
        };
    },
    stringify: function (levelObj) {
        var opened = levelObj.opened, nested = levelObj.nested, subLevel = levelObj.subLevel;
        var levelName = levelObj.levelName; // let for chalifying later on
        var arrows = ['⇒', '⇓', '⇨', '⇩'];
        var option = '';
        option += '  '.repeat(nested);
        if (nested > 1) {
            option += levelName;
        }
        else if (nested === 1) {
            // middle level
            option += opened ? arrows[1] : arrows[0];
            if (subLevel[0].html !== '') {
                option += " " + levelName + " - ENTER for (" + subLevel.length + ") total error location(s)";
            }
            else {
                option += " " + levelName + " - ENTER for URL to more information";
            }
            option = chalk_1.default.blueBright(option);
        }
        else {
            // top level
            option += opened ? arrows[1] : arrows[0];
            var subIssues_1 = 0;
            if (subLevel.length) {
                subLevel.forEach(function (issue) {
                    if (issue.specificIssues.length)
                        subIssues_1 += issue.specificIssues.length;
                });
            } // build and chalkify based on severity
            if (levelName !== 'manualTests') {
                if (levelName === 'critical')
                    levelName = chalk_1.default.hex('#FF0000')(levelName);
                else if (levelName === 'serious')
                    levelName = chalk_1.default.hex('#E66000')(levelName);
                else if (levelName === 'moderate')
                    levelName = chalk_1.default.hex('#CC0077')(levelName);
                else
                    levelName = chalk_1.default.magentaBright(levelName);
                option += " " + levelName + " (" + subLevel.length + ") issues type(s), (" + subIssues_1 + ") total error location(s)";
            }
            else {
                option += " " + chalk_1.default.hex('#00A5A5')('manual tests') + " ENTER for more information regarding manual testing";
            }
        }
        return option;
    }
};
